diff --git a/.env.example b/.env.example
index 16e00691a..39dc29756 100644
--- a/.env.example
+++ b/.env.example
@@ -30,6 +30,8 @@ MAIL_PORT=2525
MAIL_USERNAME=null
MAIL_PASSWORD=null
MAIL_ENCRYPTION=null
+SHOP_MAIL_FROM=shop@bagsaas.com
+ADMIN_MAIL_TO=admin@bagsaas.com
PUSHER_APP_ID=
PUSHER_APP_KEY=
diff --git a/packages/Webkul/Admin/src/Mail/NewAdminNotification.php b/packages/Webkul/Admin/src/Mail/NewAdminNotification.php
new file mode 100644
index 000000000..fa9d5d199
--- /dev/null
+++ b/packages/Webkul/Admin/src/Mail/NewAdminNotification.php
@@ -0,0 +1,49 @@
+
+ * @copyright 2018 Webkul Software Pvt Ltd (http://www.webkul.com)
+ */
+class NewAdminNotification extends Mailable
+{
+ use Queueable, SerializesModels;
+
+ /**
+ * The order instance.
+ *
+ * @var Order
+ */
+ public $order;
+
+
+ /**
+ * Create a new message instance.
+ *
+ * @return void
+ */
+ public function __construct($order)
+ {
+ $this->order = $order;
+ }
+
+ /**
+ * Build the message.
+ *
+ * @return $this
+ */
+ public function build()
+ {
+ return $this->to(env('ADMIN_MAIL_TO'))
+ ->subject(trans('shop::app.mail.order.subject'))
+ ->view('shop::emails.sales.new-admin-order');
+ }
+}
\ No newline at end of file
diff --git a/packages/Webkul/Admin/src/Resources/lang/en/app.php b/packages/Webkul/Admin/src/Resources/lang/en/app.php
index a65f28114..8c67db9a3 100755
--- a/packages/Webkul/Admin/src/Resources/lang/en/app.php
+++ b/packages/Webkul/Admin/src/Resources/lang/en/app.php
@@ -873,7 +873,8 @@ return [
'newsletter' => 'NewsLetter Subscription',
'newsletter-subscription' => 'Allow NewsLetter Subscription',
'email' => 'Email Verification',
- 'email-verification' => 'Allow Email Verification'
+ 'email-verification' => 'Allow Email Verification',
+ 'sort_order' => 'Sort Order'
]
]
];
diff --git a/packages/Webkul/Admin/src/Resources/views/catalog/categories/create.blade.php b/packages/Webkul/Admin/src/Resources/views/catalog/categories/create.blade.php
index a1b838e53..36f463e60 100755
--- a/packages/Webkul/Admin/src/Resources/views/catalog/categories/create.blade.php
+++ b/packages/Webkul/Admin/src/Resources/views/catalog/categories/create.blade.php
@@ -93,16 +93,17 @@
@{{ errors.first('display_mode') }}
-
-
{{ __('admin::app.catalog.categories.image') }}
+
+ {{ __('admin::app.catalog.categories.image') }}
-
+
+
+
+ {{ $errors->first('image.*') }}
+
@@ -192,6 +192,16 @@
@push('scripts')
+
+
@endpush
\ No newline at end of file
diff --git a/packages/Webkul/Customer/src/Http/Controllers/RegistrationController.php b/packages/Webkul/Customer/src/Http/Controllers/RegistrationController.php
index 7fdd36429..b483f3716 100755
--- a/packages/Webkul/Customer/src/Http/Controllers/RegistrationController.php
+++ b/packages/Webkul/Customer/src/Http/Controllers/RegistrationController.php
@@ -66,7 +66,7 @@ class RegistrationController extends Controller
$data['channel_id'] = core()->getCurrentChannel()->id;
- if(core()->getConfigData( 'customer.settings.email.verification')) {
+ if (core()->getConfigData('customer.settings.email.verification')) {
$data['is_verified'] = 0;
} else {
$data['is_verified'] = 1;
@@ -87,9 +87,9 @@ class RegistrationController extends Controller
Event::fire('customer.registration.after', $customer);
if ($customer) {
- if (core()->getConfigData( 'customer.settings.email.verification')) {
+ if (core()->getConfigData('customer.settings.email.verification')) {
try {
- Mail::send(new VerificationEmail($verificationData));
+ Mail::queue(new VerificationEmail($verificationData));
session()->flash('success', trans('shop::app.customer.signup-form.success-verify'));
} catch (\Exception $e) {
@@ -137,7 +137,7 @@ class RegistrationController extends Controller
$this->customer->update(['token' => $verificationData['token']], $customer->id);
try {
- Mail::send(new VerificationEmail($verificationData));
+ Mail::queue(new VerificationEmail($verificationData));
if (Cookie::has('enable-resend')) {
\Cookie::queue(\Cookie::forget('enable-resend'));
@@ -146,7 +146,7 @@ class RegistrationController extends Controller
if (Cookie::has('email-for-resend')) {
\Cookie::queue(\Cookie::forget('email-for-resend'));
}
- } catch(\Exception $e) {
+ } catch (\Exception $e) {
session()->flash('error', trans('shop::app.customer.signup-form.verification-not-sent'));
return redirect()->back();
@@ -155,4 +155,4 @@ class RegistrationController extends Controller
return redirect()->back();
}
-}
\ No newline at end of file
+}
diff --git a/packages/Webkul/Payment/src/Config/paymentmethods.php b/packages/Webkul/Payment/src/Config/paymentmethods.php
index bfd1ae357..5f5b6433c 100755
--- a/packages/Webkul/Payment/src/Config/paymentmethods.php
+++ b/packages/Webkul/Payment/src/Config/paymentmethods.php
@@ -5,7 +5,8 @@ return [
'title' => 'Cash On Delivery',
'description' => 'Cash On Delivery',
'class' => 'Webkul\Payment\Payment\CashOnDelivery',
- 'active' => true
+ 'active' => true,
+ 'sort' => 1
],
'moneytransfer' => [
@@ -13,7 +14,8 @@ return [
'title' => 'Money Transfer',
'description' => 'Money Transfer',
'class' => 'Webkul\Payment\Payment\MoneyTransfer',
- 'active' => true
+ 'active' => true,
+ 'sort' => 2
],
'paypal_standard' => [
@@ -23,6 +25,7 @@ return [
'class' => 'Webkul\Paypal\Payment\Standard',
'sandbox' => true,
'active' => true,
- 'business_account' => 'test@webkul.com'
+ 'business_account' => 'test@webkul.com',
+ 'sort' => 3
]
];
\ No newline at end of file
diff --git a/packages/Webkul/Payment/src/Config/system.php b/packages/Webkul/Payment/src/Config/system.php
index a2c55aea2..2e97888c1 100755
--- a/packages/Webkul/Payment/src/Config/system.php
+++ b/packages/Webkul/Payment/src/Config/system.php
@@ -41,6 +41,25 @@ return [
]
],
'validation' => 'required'
+ ], [
+ 'name' => 'sort',
+ 'title' => 'admin::app.admin.system.sort_order',
+ 'type' => 'select',
+ 'options' => [
+ [
+ 'title' => '1',
+ 'value' => 1
+ ], [
+ 'title' => '2',
+ 'value' => 2
+ ], [
+ 'title' => '3',
+ 'value' => 3
+ ], [
+ 'title' => '4',
+ 'value' => 4
+ ]
+ ],
]
]
], [
@@ -75,6 +94,25 @@ return [
]
],
'validation' => 'required'
+ ], [
+ 'name' => 'sort',
+ 'title' => 'admin::app.admin.system.sort_order',
+ 'type' => 'select',
+ 'options' => [
+ [
+ 'title' => '1',
+ 'value' => 1
+ ], [
+ 'title' => '2',
+ 'value' => 2
+ ], [
+ 'title' => '3',
+ 'value' => 3
+ ], [
+ 'title' => '4',
+ 'value' => 4
+ ]
+ ],
]
]
], [
@@ -115,6 +153,25 @@ return [
]
],
'validation' => 'required'
+ ], [
+ 'name' => 'sort',
+ 'title' => 'admin::app.admin.system.sort_order',
+ 'type' => 'select',
+ 'options' => [
+ [
+ 'title' => '1',
+ 'value' => 1
+ ], [
+ 'title' => '2',
+ 'value' => 2
+ ], [
+ 'title' => '3',
+ 'value' => 3
+ ], [
+ 'title' => '4',
+ 'value' => 4
+ ]
+ ],
]
]
]
diff --git a/packages/Webkul/Payment/src/Payment.php b/packages/Webkul/Payment/src/Payment.php
index fbd8a1ece..9f56fb521 100755
--- a/packages/Webkul/Payment/src/Payment.php
+++ b/packages/Webkul/Payment/src/Payment.php
@@ -13,6 +13,21 @@ class Payment
* @return array
*/
public function getSupportedPaymentMethods()
+ {
+ $paymentMethods = $this->getPaymentMethods();
+
+ return [
+ 'jump_to_section' => 'payment',
+ 'html' => view('shop::checkout.onepage.payment', compact('paymentMethods'))->render()
+ ];
+ }
+
+ /**
+ * Returns all supported payment methods
+ *
+ * @return array
+ */
+ public function getPaymentMethods()
{
$paymentMethods = [];
@@ -24,14 +39,20 @@ class Payment
'method' => $object->getCode(),
'method_title' => $object->getTitle(),
'description' => $object->getDescription(),
+ 'sort' => $object->getSortOrder(),
];
}
}
- return [
- 'jump_to_section' => 'payment',
- 'html' => view('shop::checkout.onepage.payment', compact('paymentMethods'))->render()
- ];
+ usort ($paymentMethods, function($a, $b) {
+ if ($a['sort'] == $b['sort']) {
+ return 0;
+ }
+
+ return ($a['sort'] < $b['sort']) ? -1 : 1;
+ });
+
+ return $paymentMethods;
}
/**
diff --git a/packages/Webkul/Payment/src/Payment/Payment.php b/packages/Webkul/Payment/src/Payment/Payment.php
index 5b0e90d2b..f2acea2d1 100755
--- a/packages/Webkul/Payment/src/Payment/Payment.php
+++ b/packages/Webkul/Payment/src/Payment/Payment.php
@@ -13,7 +13,7 @@ abstract class Payment
* @var Cart
*/
protected $cart;
-
+
/**
* Checks if payment method is available
*
@@ -109,4 +109,14 @@ abstract class Payment
return $this->cart->items;
}
+
+ /**
+ * Returns payment method sort order
+ *
+ * @return array
+ */
+ public function getSortOrder()
+ {
+ return $this->getConfigData('sort');
+ }
}
\ No newline at end of file
diff --git a/packages/Webkul/Product/src/Repositories/ProductRepository.php b/packages/Webkul/Product/src/Repositories/ProductRepository.php
index 736406593..a0ff966ae 100755
--- a/packages/Webkul/Product/src/Repositories/ProductRepository.php
+++ b/packages/Webkul/Product/src/Repositories/ProductRepository.php
@@ -442,7 +442,7 @@ class ProductRepository extends Repository
->addSelect('product_flat.*')
->addSelect(DB::raw('IF( product_flat.special_price_from IS NOT NULL
AND product_flat.special_price_to IS NOT NULL , IF( NOW( ) >= product_flat.special_price_from
- AND NOW( ) <= product_flat.special_price_to, IF( product_flat.special_price IS NULL OR product_flat.special_price = 0 , product_flat.price, LEAST( product_flat.special_price, product_flat.price ) ) , product_flat.price ) , IF( product_flat.special_price_from IS NULL , IF( product_flat.special_price_to IS NULL , IF( product_flat.special_price IS NULL OR product_flat.special_price = 0 , product_flat.price, LEAST( product_flat.special_price, product_flat.price ) ) , IF( NOW( ) <= product_flat.special_price_to, IF( product_flat.special_price IS NULL OR product_flat.special_price = 0 , product_flat.price, LEAST( product_flat.special_price, product_flat.price ) ) , product_flat.price ) ) , IF( product_flat.special_price_to IS NULL , IF( NOW( ) >= product_flat.special_price_from, IF( product_flat.special_price IS NULL OR product_flat.special_price = 0 , product_flat.price, LEAST( product_flat.special_price, product_flat.price ) ) , product_flat.price ) , product_flat.price ) ) ) AS price'))
+ AND NOW( ) <= product_flat.special_price_to, IF( product_flat.special_price IS NULL OR product_flat.special_price = 0 , product_flat.price, LEAST( product_flat.special_price, product_flat.price ) ) , product_flat.price ) , IF( product_flat.special_price_from IS NULL , IF( product_flat.special_price_to IS NULL , IF( product_flat.special_price IS NULL OR product_flat.special_price = 0 , product_flat.price, LEAST( product_flat.special_price, product_flat.price ) ) , IF( NOW( ) <= product_flat.special_price_to, IF( product_flat.special_price IS NULL OR product_flat.special_price = 0 , product_flat.price, LEAST( product_flat.special_price, product_flat.price ) ) , product_flat.price ) ) , IF( product_flat.special_price_to IS NULL , IF( NOW( ) >= product_flat.special_price_from, IF( product_flat.special_price IS NULL OR product_flat.special_price = 0 , product_flat.price, LEAST( product_flat.special_price, product_flat.price ) ) , product_flat.price ) , product_flat.price ) ) ) AS final_price'))
->leftJoin('products', 'product_flat.product_id', '=', 'products.id')
->leftJoin('product_categories', 'products.id', '=', 'product_categories.product_id')
@@ -472,7 +472,11 @@ class ProductRepository extends Repository
$attribute = $this->attribute->findOneByField('code', $params['sort']);
if ($params['sort'] == 'price') {
- $qb->orderBy($attribute->code, $params['order']);
+ if ($attribute->code == 'price') {
+ $qb->orderBy('final_price', $params['order']);
+ } else {
+ $qb->orderBy($attribute->code, $params['order']);
+ }
} else {
$qb->orderBy($params['sort'] == 'created_at' ? 'product_flat.created_at' : $attribute->code, $params['order']);
}
@@ -495,7 +499,11 @@ class ProductRepository extends Repository
}
});
} else {
- $query2 = $query2->where($column, '>=', current($queryParams))->where($column, '<=', end($queryParams));
+ if ($attribute->code != 'price') {
+ $query2 = $query2->where($column, '>=', current($queryParams))->where($column, '<=', end($queryParams));
+ } else {
+ $query2 = $query2->where($column, '>=', current($queryParams))->where($column, '<=', end($queryParams));
+ }
}
}
});
diff --git a/packages/Webkul/Shop/src/Http/Controllers/SubscriptionController.php b/packages/Webkul/Shop/src/Http/Controllers/SubscriptionController.php
index 67ba05775..f027e8964 100755
--- a/packages/Webkul/Shop/src/Http/Controllers/SubscriptionController.php
+++ b/packages/Webkul/Shop/src/Http/Controllers/SubscriptionController.php
@@ -67,8 +67,8 @@ class SubscriptionController extends Controller
$alreadySubscribed = $this->subscription->findWhere(['email' => $email]);
- $unique = function() use($alreadySubscribed) {
- if ($alreadySubscribed->count() > 0 ) {
+ $unique = function () use ($alreadySubscribed) {
+ if ($alreadySubscribed->count() > 0) {
return 0;
} else {
return 1;
@@ -84,10 +84,10 @@ class SubscriptionController extends Controller
$mailSent = true;
try {
- Mail::send(new SubscriptionEmail($subscriptionData));
+ Mail::queue(new SubscriptionEmail($subscriptionData));
session()->flash('success', trans('shop::app.subscription.subscribed'));
- } catch(\Exception $e) {
+ } catch (\Exception $e) {
session()->flash('error', trans('shop::app.subscription.not-subscribed'));
$mailSent = false;
@@ -103,7 +103,7 @@ class SubscriptionController extends Controller
'token' => $token
]);
- if (! $result) {
+ if (!$result) {
session()->flash('error', trans('shop::app.subscription.not-subscribed'));
return redirect()->back();
@@ -121,15 +121,16 @@ class SubscriptionController extends Controller
*
* @var string $token
*/
- public function unsubscribe($token) {
+ public function unsubscribe($token)
+ {
$subscriber = $this->subscription->findOneByField('token', $token);
if (isset($subscriber))
- if ($subscriber->count() > 0 && $subscriber->is_subscribed == 1 &&$subscriber->update(['is_subscribed' => 0])) {
- session()->flash('info', trans('shop::app.subscription.unsubscribed'));
- } else {
- session()->flash('info', trans('shop::app.subscription.already-unsub'));
- }
+ if ($subscriber->count() > 0 && $subscriber->is_subscribed == 1 && $subscriber->update(['is_subscribed' => 0])) {
+ session()->flash('info', trans('shop::app.subscription.unsubscribed'));
+ } else {
+ session()->flash('info', trans('shop::app.subscription.already-unsub'));
+ }
return redirect()->route('shop.home.index');
}
diff --git a/packages/Webkul/Shop/src/Resources/assets/sass/app.scss b/packages/Webkul/Shop/src/Resources/assets/sass/app.scss
index 63fccb948..251b91c8d 100755
--- a/packages/Webkul/Shop/src/Resources/assets/sass/app.scss
+++ b/packages/Webkul/Shop/src/Resources/assets/sass/app.scss
@@ -3581,6 +3581,10 @@ section.review {
left: unset !important;
right: 100% !important;
}
+
+ .nav ul {
+ left: 99999em;
+ }
}
.search-responsive .search-content .right {
diff --git a/packages/Webkul/Shop/src/Resources/lang/en/app.php b/packages/Webkul/Shop/src/Resources/lang/en/app.php
index 17b70d77c..a5a3fcdec 100755
--- a/packages/Webkul/Shop/src/Resources/lang/en/app.php
+++ b/packages/Webkul/Shop/src/Resources/lang/en/app.php
@@ -457,7 +457,9 @@ return [
'subject' => 'New Order Confirmation',
'heading' => 'Order Confirmation!',
'dear' => 'Dear :customer_name',
+ 'dear-admin' => 'Dear :admin_name',
'greeting' => 'Thanks for your Order :order_id placed on :created_at',
+ 'greeting-admin' => 'Order Id :order_id placed on :created_at',
'summary' => 'Summary of Order',
'shipping-address' => 'Shipping Address',
'billing-address' => 'Billing Address',
diff --git a/packages/Webkul/Shop/src/Resources/views/emails/sales/new-admin-order.blade.php b/packages/Webkul/Shop/src/Resources/views/emails/sales/new-admin-order.blade.php
new file mode 100644
index 000000000..3b194db5d
--- /dev/null
+++ b/packages/Webkul/Shop/src/Resources/views/emails/sales/new-admin-order.blade.php
@@ -0,0 +1,175 @@
+@component('shop::emails.layouts.master')
+
+
+
+
+
+ {{ __('shop::app.mail.order.heading') }}
+
+
+
+ {{ __('shop::app.mail.order.dear-admin', ['admin_name' => config('mail.from.name')]) }},
+
+
+
+ {!! __('shop::app.mail.order.greeting-admin', [
+ 'order_id' => '#' . $order->id . ' ',
+ 'created_at' => $order->created_at
+ ])
+ !!}
+
+
+
+
+ {{ __('shop::app.mail.order.summary') }}
+
+
+
+
+
+ {{ __('shop::app.mail.order.shipping-address') }}
+
+
+
+ {{ $order->shipping_address->name }}
+
+
+
+ {{ $order->shipping_address->address1 }}, {{ $order->shipping_address->state }}
+
+
+
+ {{ country()->name($order->shipping_address->country) }} {{ $order->shipping_address->postcode }}
+
+
+
---
+
+
+ {{ __('shop::app.mail.order.contact') }} : {{ $order->shipping_address->phone }}
+
+
+
+ {{ __('shop::app.mail.order.shipping') }}
+
+
+
+ {{ $order->shipping_title }}
+
+
+
+
+
+ {{ __('shop::app.mail.order.billing-address') }}
+
+
+
+ {{ $order->billing_address->name }}
+
+
+
+ {{ $order->billing_address->address1 }}, {{ $order->billing_address->state }}
+
+
+
+ {{ country()->name($order->billing_address->country) }} {{ $order->billing_address->postcode }}
+
+
+
---
+
+
+ {{ __('shop::app.mail.order.contact') }} : {{ $order->billing_address->phone }}
+
+
+
+ {{ __('shop::app.mail.order.payment') }}
+
+
+
+ {{ core()->getConfigData('sales.paymentmethods.' . $order->payment->method . '.title') }}
+
+
+
+
+ @foreach ($order->items as $item)
+
+
+ {{ $item->name }}
+
+
+
+
+ {{ __('shop::app.mail.order.price') }}
+
+
+ {{ core()->formatPrice($item->price, $order->order_currency_code) }}
+
+
+
+
+
+ {{ __('shop::app.mail.order.quantity') }}
+
+
+ {{ $item->qty_ordered }}
+
+
+
+ @if ($html = $item->getOptionDetailHtml())
+
+
+ {{ $html }}
+
+
+ @endif
+
+ @endforeach
+
+
+
+ {{ __('shop::app.mail.order.subtotal') }}
+
+ {{ core()->formatPrice($order->sub_total, $order->order_currency_code) }}
+
+
+
+
+ {{ __('shop::app.mail.order.shipping-handling') }}
+
+ {{ core()->formatPrice($order->shipping_amount, $order->order_currency_code) }}
+
+
+
+
+ {{ __('shop::app.mail.order.tax') }}
+
+ {{ core()->formatPrice($order->tax_amount, $order->order_currency_code) }}
+
+
+
+
+ {{ __('shop::app.mail.order.grand-total') }}
+
+ {{ core()->formatPrice($order->grand_total, $order->order_currency_code) }}
+
+
+
+
+
+
+ {!!
+ __('shop::app.mail.order.help', [
+ 'support_email' => '' . env('ADMIN_MAIL_TO'). ' '
+ ])
+ !!}
+
+
+
+ {{ __('shop::app.mail.order.thanks') }}
+
+
+
+@endcomponent
diff --git a/packages/Webkul/Shop/src/Resources/views/products/review-price.blade.php b/packages/Webkul/Shop/src/Resources/views/products/review-price.blade.php
new file mode 100644
index 000000000..4a69f26af
--- /dev/null
+++ b/packages/Webkul/Shop/src/Resources/views/products/review-price.blade.php
@@ -0,0 +1,13 @@
+
+ @inject ('priceHelper', 'Webkul\Product\Helpers\Price')
+
+ @if ($product->type == 'configurable')
+ {{ core()->currency($priceHelper->getMinimalPrice($product)) }}
+ @else
+ @if ($priceHelper->haveSpecialPrice($product))
+ {{ core()->currency($priceHelper->getSpecialPrice($product)) }}
+ @else
+ {{ core()->currency($product->price) }}
+ @endif
+ @endif
+
\ No newline at end of file
diff --git a/packages/Webkul/Shop/src/Resources/views/products/reviews/create.blade.php b/packages/Webkul/Shop/src/Resources/views/products/reviews/create.blade.php
index 29983069b..b258bc1d8 100755
--- a/packages/Webkul/Shop/src/Resources/views/products/reviews/create.blade.php
+++ b/packages/Webkul/Shop/src/Resources/views/products/reviews/create.blade.php
@@ -26,19 +26,8 @@
-
- @inject ('priceHelper', 'Webkul\Product\Helpers\Price')
+ @include('shop::products.review-price')
- @if ($product->type == 'configurable')
- {{ core()->currency($priceHelper->getMinimalPrice($product)) }}
- @else
- @if ($priceHelper->haveSpecialPrice($product))
- {{ core()->currency($priceHelper->getSpecialPrice($product)) }}
- @else
- {{ core()->currency($product->price) }}
- @endif
- @endif
-
diff --git a/packages/Webkul/Ui/src/Resources/views/datagrid/table.blade.php b/packages/Webkul/Ui/src/Resources/views/datagrid/table.blade.php
index bc9c727bf..9c45da34d 100644
--- a/packages/Webkul/Ui/src/Resources/views/datagrid/table.blade.php
+++ b/packages/Webkul/Ui/src/Resources/views/datagrid/table.blade.php
@@ -634,8 +634,16 @@
obj.label = '';
for(colIndex in this.columns) {
- if(this.columns[colIndex].index == obj.column) {
+ if (this.columns[colIndex].index == obj.column) {
obj.label = this.columns[colIndex].label;
+
+ if (this.columns[colIndex].type == 'boolean') {
+ if (obj.val == 1) {
+ obj.val = '{{ __('ui::app.datagrid.true') }}';
+ } else {
+ obj.val = '{{ __('ui::app.datagrid.false') }}';
+ }
+ }
}
}
}
diff --git a/public/installer/AdminConfig.php b/public/installer/AdminConfig.php
index 6bb38798c..cfb17829b 100755
--- a/public/installer/AdminConfig.php
+++ b/public/installer/AdminConfig.php
@@ -100,6 +100,8 @@ $data = array();
$data['support_error'] = 'Bagisto currently support MySQL only. Press OK to still continue or change you DB connection to MySQL';
}
+ $storage_output = exec('cd ../.. && php artisan storage:link 2>&1');
+
// if there are no errors process our form, then return a message
// show a message of success and provide a true success variable
$data['success'] = true;
diff --git a/public/installer/index.php b/public/installer/index.php
index 7edc6a201..46853c3f3 100755
--- a/public/installer/index.php
+++ b/public/installer/index.php
@@ -120,8 +120,6 @@
// object creation
$requirement = new Requirement();
echo $requirement->render();
-
- $storage_output = exec('cd ../.. && php artisan storage:link 2>&1');
} else {
// getting url
$actual_link = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
diff --git a/packages/Webkul/Admin/src/Listeners/Order.php b/packages/Webkul/Admin/src/Listeners/Order.php
index 4f86b938a..eb7939ecd 100755
--- a/packages/Webkul/Admin/src/Listeners/Order.php
+++ b/packages/Webkul/Admin/src/Listeners/Order.php
@@ -20,12 +20,14 @@ class Order {
/**
* @param mixed $order
*
* Send new shipment mail to the customer and inventory source
*/
public function sendNewOrderMail($order)
{
try {
- Mail::send(new NewOrderNotification($order));
+ Mail::queue(new NewOrderNotification($order));
+
+ Mail::queue(new NewAdminNotification($order));
} catch (\Exception $e) {
}
@@ -40,7 +42,7 @@ class Order {
public function sendNewInvoiceMail($invoice)
{
try {
- Mail::send(new NewInvoiceNotification($invoice));
+ Mail::queue(new NewInvoiceNotification($invoice));
} catch (\Exception $e) {
}
@@ -54,9 +56,9 @@ class Order {
public function sendNewShipmentMail($shipment)
{
try {
- Mail::send(new NewShipmentNotification($shipment));
+ Mail::queue(new NewShipmentNotification($shipment));
- Mail::send(new NewInventorySourceNotification($shipment));
+ Mail::queue(new NewInventorySourceNotification($shipment));
} catch (\Exception $e) {
}
@@ -20,12 +20,14 @@ class Order {
* @param mixed $order
*
- * Send new shipment mail to the customer and inventory source
+ * Send new order Mail to the customer and admin
*/
public function sendNewOrderMail($order)